@@ -10,9 +10,10 @@ import numpy as np
 from connectome import Source, meta
 from connectome.interface.nodes import Silent
 
-from .internals import checksum
+from .internals import checksum, register
 
 
+@register()
 @checksum('verse')
 class VerSe(Source):
     """
